@@ -28,7 +28,7 @@ BEGIN {
     }
 }
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 sub _ANYPROCESS                    { return -1 }
 sub _COMMAND                       { return 0 }
@@ -672,6 +672,14 @@ sub _create_capabilities {
 }
 
 sub find_elements {
+    my ( $self, $value, $using ) = @_;
+    Carp::carp(
+        '**** DEPRECATED METHOD - find_elements HAS BEEN REPLACED BY list ****'
+    );
+    return $self->find( $value, $using );
+}
+
+sub list {
     my ( $self, $value, $using ) = @_;
     $using ||= 'xpath';
     my $message_id = $self->_new_message_id();
@@ -795,6 +803,13 @@ sub is_displayed {
 }
 
 sub send_keys {
+    my ( $self, $element, $text ) = @_;
+    Carp::carp(
+        '**** DEPRECATED METHOD - send_keys HAS BEEN REPLACED BY type ****');
+    return $self->type( $element, $text );
+}
+
+sub type {
     my ( $self, $element, $text ) = @_;
     if (
         !(
@@ -804,8 +819,7 @@ sub send_keys {
       )
     {
         Carp::croak(
-            'send_keys method requires a Firefox::Marionette::Element parameter'
-        );
+            'type method requires a Firefox::Marionette::Element parameter');
     }
     my $message_id = $self->_new_message_id();
     $self->_send_request(
@@ -1313,6 +1327,13 @@ sub attribute {
 }
 
 sub find_element {
+    my ( $self, $value, $using ) = @_;
+    Carp::carp(
+        '**** DEPRECATED METHOD - find_element HAS BEEN REPLACED BY find ****');
+    return $self->find( $value, $using );
+}
+
+sub find {
     my ( $self, $value, $using ) = @_;
     $using ||= 'xpath';
     my $message_id = $self->_new_message_id();
@@ -1498,7 +1519,7 @@ sub script {
     return $response->result()->{value};
 }
 
-sub page_source {
+sub html {
     my ($self) = @_;
     my $message_id = $self->_new_message_id();
     $self->_send_request(
@@ -1511,6 +1532,13 @@ sub page_source {
     return $response->result()->{value};
 }
 
+sub page_source {
+    my ($self) = @_;
+    Carp::carp(
+        '**** DEPRECATED METHOD - page_source HAS BEEN REPLACED BY html ****');
+    return $self->html();
+}
+
 sub back {
     my ($self) = @_;
     my $message_id = $self->_new_message_id();
@@ -1633,70 +1661,6 @@ sub uninstall {
     return $self;
 }
 
-my $x = <<'_DOC_';
-  // WebDriver service
-#  "WebDriver:AcceptDialog": GeckoDriver.prototype.acceptDialog,
-#  "WebDriver:AddCookie": GeckoDriver.prototype.addCookie,
-#  "WebDriver:Back": GeckoDriver.prototype.goBack,
-#  "WebDriver:CloseChromeWindow": GeckoDriver.prototype.closeChromeWindow,
-#  "WebDriver:CloseWindow": GeckoDriver.prototype.close,
-#  "WebDriver:DeleteAllCookies": GeckoDriver.prototype.deleteAllCookies,
-#  "WebDriver:DeleteCookie": GeckoDriver.prototype.deleteCookie,
-#  "WebDriver:DeleteSession": GeckoDriver.prototype.deleteSession,
-#  "WebDriver:DismissAlert": GeckoDriver.prototype.dismissDialog,
-#  "WebDriver:ElementClear": GeckoDriver.prototype.clearElement,
-#  "WebDriver:ElementClick": GeckoDriver.prototype.clickElement,
-#  "WebDriver:ElementSendKeys": GeckoDriver.prototype.sendKeysToElement,
-#  "WebDriver:ExecuteAsyncScript": GeckoDriver.prototype.executeAsyncScript,
-#  "WebDriver:ExecuteScript": GeckoDriver.prototype.executeScript,
-#  "WebDriver:FindElement": GeckoDriver.prototype.findElement,
-#  "WebDriver:FindElements": GeckoDriver.prototype.findElements,
-#  "WebDriver:Forward": GeckoDriver.prototype.goForward,
-#  "WebDriver:FullscreenWindow": GeckoDriver.prototype.fullscreenWindow,
-#  "WebDriver:GetActiveElement": GeckoDriver.prototype.getActiveElement,
-#  "WebDriver:GetActiveFrame": GeckoDriver.prototype.getActiveFrame,
-#  "WebDriver:GetAlertText": GeckoDriver.prototype.getTextFromDialog,
-#  "WebDriver:GetCapabilities": GeckoDriver.prototype.getSessionCapabilities,
-#  "WebDriver:GetChromeWindowHandle": GeckoDriver.prototype.getChromeWindowHandle,
-#  "WebDriver:GetChromeWindowHandles": GeckoDriver.prototype.getChromeWindowHandles,
-#  "WebDriver:GetCookies": GeckoDriver.prototype.getCookies,
-#  "WebDriver:GetCurrentChromeWindowHandle": GeckoDriver.prototype.getChromeWindowHandle,
-#  "WebDriver:GetCurrentURL": GeckoDriver.prototype.getCurrentUrl,
-#  "WebDriver:GetElementAttribute": GeckoDriver.prototype.getElementAttribute,
-#  "WebDriver:GetElementCSSValue": GeckoDriver.prototype.getElementValueOfCssProperty,
-#  "WebDriver:GetElementProperty": GeckoDriver.prototype.getElementProperty,
-#  "WebDriver:GetElementRect": GeckoDriver.prototype.getElementRect,
-#  "WebDriver:GetElementTagName": GeckoDriver.prototype.getElementTagName,
-#  "WebDriver:GetElementText": GeckoDriver.prototype.getElementText,
-#  "WebDriver:GetPageSource": GeckoDriver.prototype.getPageSource,
-#  "WebDriver:GetScreenOrientation": GeckoDriver.prototype.getScreenOrientation,
-#  "WebDriver:GetTimeouts": GeckoDriver.prototype.getTimeouts,
-#  "WebDriver:GetTitle": GeckoDriver.prototype.getTitle,
-#  "WebDriver:GetWindowHandle": GeckoDriver.prototype.getWindowHandle,
-#  "WebDriver:GetWindowHandles": GeckoDriver.prototype.getWindowHandles,
-#  "WebDriver:GetWindowRect": GeckoDriver.prototype.getWindowRect,
-#  "WebDriver:GetWindowType": GeckoDriver.prototype.getWindowType,
-#  "WebDriver:IsElementDisplayed": GeckoDriver.prototype.isElementDisplayed,
-#  "WebDriver:IsElementEnabled": GeckoDriver.prototype.isElementEnabled,
-#  "WebDriver:IsElementSelected": GeckoDriver.prototype.isElementSelected,
-#  "WebDriver:MinimizeWindow": GeckoDriver.prototype.minimizeWindow,
-#  "WebDriver:MaximizeWindow": GeckoDriver.prototype.maximizeWindow,
-#  "WebDriver:Navigate": GeckoDriver.prototype.get,
-#  "WebDriver:NewSession": GeckoDriver.prototype.newSession,
-  "WebDriver:PerformActions": GeckoDriver.prototype.performActions,
-#  "WebDriver:Refresh":  GeckoDriver.prototype.refresh,
-  "WebDriver:ReleaseActions": GeckoDriver.prototype.releaseActions,
-#  "WebDriver:SendAlertText": GeckoDriver.prototype.sendKeysToDialog,
-  "WebDriver:SetScreenOrientation": GeckoDriver.prototype.setScreenOrientation
-#  "WebDriver:SetTimeouts": GeckoDriver.prototype.setTimeouts,
-#  "WebDriver:SetWindowRect": GeckoDriver.prototype.setWindowRect,
-#  "WebDriver:SwitchToFrame": GeckoDriver.prototype.switchToFrame,
-#  "WebDriver:SwitchToParentFrame": GeckoDriver.prototype.switchToParentFrame,
-#  "WebDriver:SwitchToShadowRoot": GeckoDriver.prototype.switchToShadowRoot,
-#  "WebDriver:SwitchToWindow": GeckoDriver.prototype.switchToWindow,
-#  "WebDriver:TakeScreenshot": GeckoDriver.prototype.takeScreenshot,
-_DOC_
-
 sub marionette_protocol {
     my ($self) = @_;
     return $self->{marionette_protocol};
@@ -1812,7 +1776,7 @@ Firefox::Marionette - Automate the Firefox browser with the Marionette protocol
 
 =head1 VERSION
 
-Version 0.30
+Version 0.31
 
 =head1 SYNOPSIS
 
@@ -1821,13 +1785,13 @@ Version 0.30
 
     my $firefox = Firefox::Marionette->new()->go('https://metacpan.org/');
 
-    $firefox->find_element('//input[@id="search-input"]')->send_keys('Test::More');
+    $firefox->find('//input[@id="search-input"]')->type('Test::More');
 
-    my $file_handle = $firefox->selfie(highlights => [ $firefox->find_element('//button[@name="lucky"]') ])
+    my $file_handle = $firefox->selfie(highlights => [ $firefox->find('//button[@name="lucky"]') ])
 
-    $firefox->find_element('//button[@name="lucky"]')->click();
+    $firefox->find('//button[@name="lucky"]')->click();
 
-    say $firefox->page_source();
+    say $firefox->html();
 
     $firefox->install('/full/path/to/gnu_terry_pratchett-0.4-an+fx.xpi');
 
@@ -1875,6 +1839,10 @@ returns the current title of the window.
 
 =head2 find_element
 
+*** DEPRECATED - see L<find|Firefox::Marionette#find>. ***
+
+=head2 find
+
 returns the first element in the current browsing context that matches the search parameters supplied;
 
 =over 4
@@ -1889,7 +1857,11 @@ This method is subject to the L<implicit|Firefox::Marionette::Timeouts#implicit>
 
 =head2 find_elements
 
-returns the elements in the current browsing context that match the search parameters supplied;
+*** DEPRECATED - see L<list|Firefox::Marionette#list>. ***
+
+=head2 list
+
+returns all the elements in the current browsing context that match the search parameters supplied;
 
 =over 4
 
@@ -1927,6 +1899,10 @@ The executing javascript is subject to the L<scripts|Firefox::Marionette::Timeou
 
 =head2 page_source
 
+*** DEPRECATED - see L<html|Firefox::Marionette#html>. ***
+
+=head2 html
+
 returns the page source of the content document.
 
 =head2 context
@@ -1951,6 +1927,10 @@ returns the contents of the cookie jar in scalar or list context.
 
 =head2 send_keys
 
+*** DEPRECATED - see L<type|Firefox::Marionette#type>. ***
+
+=head2 type
+
 accepts an L<element|Firefox::Marionette::Element> as the first parameter and a string as the second parameter.  It sends the string to the specified L<element|Firefox::Marionette::Element> in the current page, such as filling out a text box. This method returns L<itself|Firefox::Marionette> to aid in chaining methods.
 
 =head2 is_displayed
@@ -2043,7 +2023,7 @@ returns the L<capabilities|Firefox::Marionette::Capabilities> of the current fir
 
 =head2 screen_orientation
 
-returns the current browser orientation.  This will be one of the valid primary orientation values 'portrait-primary', 'landscape-primary', 'portrait-secondary', or 'landscape-secondary'.
+returns the current browser orientation.  This will be one of the valid primary orientation values 'portrait-primary', 'landscape-primary', 'portrait-secondary', or 'landscape-secondary'.  This method is only currently available on Android (Fennec).
 
 =head2 selfie
 
@@ -2213,6 +2193,18 @@ None reported.
 
 =head1 BUGS AND LIMITATIONS
 
+Currently the following Marionette methods have not been implemented;
+
+=over
+ 
+=item * WebDriver:ReleaseAction
+
+=item * WebDriver:PerformActions
+
+=item * WebDriver:SetScreenOrientation
+
+=back
+
 No bugs have been reported.
 
 Please report any bugs or feature requests to
